@@ -94,6 +94,22 @@ c(PiecewisePareto_Layer_Mean(500, 1000, fit$t, fit$alpha) * fit$FQ,
 covers <- c(diff(attachment_points), Inf)
 Layer_Mean(fit, covers, attachment_points)
 
+## -----------------------------------------------------------------------------
+  covers <- c(1000, 1000, 1000)
+  att_points <- c(1000, 2000, 5000)
+  exp_losses <- c(100, 50, 10)
+  thresholds <- c(4000, 10000)
+  fqs <- c(0.04, 0.005)
+  fit <- Fit_References(covers, att_points, exp_losses, thresholds, fqs)
+  Layer_Mean(fit, covers, att_points)
+  Excess_Frequency(fit, thresholds)
+
+## -----------------------------------------------------------------------------
+return_periods <- c(1, 5, 10, 20, 50, 100)
+amounts <- c(1000, 4000, 7000, 10000, 13000, 14000)
+fit <- Fit_PML_Curve(return_periods, amounts)
+1 / Excess_Frequency(fit, amounts)
+
 ## -----------------------------------------------------------------------------
 PPPM <- PPP_Model(FQ = 2, t = c(1000, 2000), alpha = c(1, 2), 
                   truncation = 10000, truncation_type = "wd", dispersion = 1.5)
